==> haskell-string-qq-0.0.4-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-string-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 string-qq
version:              0.0.4
visibility:           public
id:                   string-qq-0.0.4-ItoFnj42QvbF27nZZpUEE5
key:                  string-qq-0.0.4-ItoFnj42QvbF27nZZpUEE5
license:              LicenseRef-PublicDomain
copyright:            Audrey Tang
maintainer:           Audrey Tang <audreyt@audreyt.org>
author:               Audrey Tang
stability:            unstable
synopsis:
    QuasiQuoter for non-interpolated strings, texts and bytestrings.

description:
    QuasiQuoter for non-interpolated strings, texts and bytestrings, useful for writing multi-line IsString literals.

category:             Data
abi:                  98fe732dac6a6572a2b0990a1c98fbb3
exposed:              True
exposed-modules:      Data.String.QQ
import-dirs:          /usr/lib/ghc-8.10.2/site-local/string-qq-0.0.4
library-dirs:         /usr/lib/ghc-8.10.2/site-local/string-qq-0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/string-qq-0.0.4
hs-libraries:         HSstring-qq-0.0.4-ItoFnj42QvbF27nZZpUEE5
depends:              base-4.14.1.0 template-haskell-2.16.0.0
haddock-interfaces:   /usr/share/doc/haskell-string-qq/html/string-qq.haddock
haddock-html:         /usr/share/doc/haskell-string-qq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-string-qq-0.0.4-27-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-string-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 string-qq
version:              0.0.4
visibility:           public
id:                   string-qq-0.0.4-5xTi2FQYvBp21A5Hbfxok4
key:                  string-qq-0.0.4-5xTi2FQYvBp21A5Hbfxok4
license:              LicenseRef-PublicDomain
copyright:            Audrey Tang
maintainer:           Audrey Tang <audreyt@audreyt.org>
author:               Audrey Tang
stability:            unstable
synopsis:
    QuasiQuoter for non-interpolated strings, texts and bytestrings.

description:
    QuasiQuoter for non-interpolated strings, texts and bytestrings, useful for writing multi-line IsString literals.

category:             Data
abi:                  a13b6f299146501f56b8bc38e378a314
exposed:              True
exposed-modules:      Data.String.QQ
import-dirs:          /usr/lib/ghc-8.10.2/site-local/string-qq-0.0.4
library-dirs:         /usr/lib/ghc-8.10.2/site-local/string-qq-0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/string-qq-0.0.4
hs-libraries:         HSstring-qq-0.0.4-5xTi2FQYvBp21A5Hbfxok4
depends:              base-4.14.1.0 template-haskell-2.16.0.0
haddock-interfaces:   /usr/share/doc/haskell-string-qq/html/string-qq.haddock
haddock-html:         /usr/share/doc/haskell-string-qq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
